/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */


package edu.stanford.smi.protegex.owl.swrl;

import edu.stanford.smi.protegex.owl.swrl.exceptions.SWRLRuleEngineException;
import edu.stanford.smi.protegex.owl.swrl.bridge.BridgeFactory;
import edu.stanford.smi.protegex.owl.swrl.bridge.exceptions.SWRLRuleEngineBridgeException;

import edu.stanford.smi.protegex.owl.model.OWLModel;

/**
 ** Factory for creating SWRL rule engines
 */
public class SWRLRuleEngineFactory
{
  public static SWRLRuleEngine create(OWLModel owlModel) throws SWRLRuleEngineException
  {
    SWRLRuleEngine ruleEngine = null;

    try {
      ruleEngine = BridgeFactory.createBridge(owlModel);
    } catch (SWRLRuleEngineBridgeException e) {
      throw new SWRLRuleEngineException("error creating SWRL rule engine: " + e.getMessage());
    } // try
    
    return ruleEngine;
  } // create

  public static SWRLRuleEngine create(String ruleEngineName, OWLModel owlModel) throws SWRLRuleEngineException
  {
    SWRLRuleEngine ruleEngine = null;

    try {
      ruleEngine = BridgeFactory.createBridge(ruleEngineName, owlModel);
    } catch (SWRLRuleEngineBridgeException e) {
      throw new SWRLRuleEngineException("error creating SWRL rule engine '" + ruleEngineName + "': " + e.getMessage());
    } // try
    
    return ruleEngine;
  } // create

} // SWRLRuleEngineFactory
