/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */


package edu.stanford.smi.protegex.owl.swrl.bridge.impl;

import edu.stanford.smi.protegex.owl.swrl.bridge.*;

import java.util.Set;
import java.util.HashSet;

/*
** Base class representing information about atoms in a SWRL rule
*/
public class AtomImpl implements Atom
{
  private Set<String> referencedClassNames;
  private Set<String> referencedPropertyNames;
  private Set<String> referencedIndividualNames;
  private Set<String> referencedVariableNames;

  public AtomImpl() 
  { 
    referencedClassNames = new HashSet<String>();
    referencedPropertyNames = new HashSet<String>();
    referencedIndividualNames = new HashSet<String>();
    referencedVariableNames = new HashSet<String>();
  } // AtomImpl

  public boolean hasReferencedClasses() { return referencedClassNames.size() != 0; }
  public Set<String> getReferencedClassNames() { return referencedClassNames; }
  public boolean hasReferencedProperties() { return referencedPropertyNames.size() != 0; }
  public Set<String> getReferencedPropertyNames() { return referencedPropertyNames; }
  public boolean hasReferencedIndividuals() { return referencedIndividualNames.size() != 0; }
  public Set<String> getReferencedIndividualNames() { return referencedIndividualNames; }
  public boolean hasReferencedVariables() { return referencedVariableNames.size() != 0; }
  public Set<String> getReferencedVariableNames() { return referencedVariableNames; }
  
  public void addReferencedClassName(String className) 
  { 
    if (!referencedClassNames.contains(className)) referencedClassNames.add(className); 
  } // addReferencedIndividualName

  public void addReferencedPropertyName(String propertyName) 
  { 
    if (!referencedPropertyNames.contains(propertyName)) referencedPropertyNames.add(propertyName); 
  } // addReferencedIndividualName

  public void addReferencedIndividualName(String individualName) 
  { 
    if (!referencedIndividualNames.contains(individualName)) referencedIndividualNames.add(individualName); 
  } // addReferencedIndividualName
  
  public void addReferencedVariableName(String variableName) 
  { 
    if (!referencedVariableNames.contains(variableName)) referencedVariableNames.add(variableName); 
  } // addReferencedVariableName
} // AtomImpl
