/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protegex.owl.ui.resourcedisplay;

import edu.stanford.smi.protege.util.Disposable;
import edu.stanford.smi.protege.util.Selectable;
import edu.stanford.smi.protegex.owl.model.RDFResource;
import edu.stanford.smi.protegex.owl.ui.widget.InferredModeWidget;

/**
 * An interface for user interface components that display a given RDFResource
 * as a form.  Instances of this are used as the main panel on the various tabs.
 *
 * @author Holger Knublauch  <holger@knublauch.com>
 */
public interface ResourcePanel extends InferredModeWidget, Selectable, Disposable {

    final static int DEFAULT_TYPE_CLASS = 0;

    final static int DEFAULT_TYPE_PROPERTY = 1;

    final static int DEFAULT_TYPE_INDIVIDUAL = 2;

    final static int DEFAULT_TYPE_ONTOLOGY = 3;


    RDFResource getResource();

    void setResource(RDFResource resource);

    void dispose();
}
